#
# __init__.py 
# Python bindings for libosso components.
#
# Copyright (C) 2005-2006 INdT - Instituto Nokia de Tecnologia
#
# Contact: Luciano Miguel Wolf <luciano.wolf@indt.org.br>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#

from context import Context
from application import Application
from autosave import Autosave
from device_state import DeviceState
#from help import Help
from locale import Locale
#from mime import Mime
from plugin import Plugin
from rpc import Rpc
from state_saving import StateSaving
from statusbar import Statusbar
from system_note import SystemNote
from time_notification import TimeNotification
#import ic
